# -*- coding: utf-8 -*-
#
# Copyright (C) 2022 KTH Royal Institute of Technology Sweden
#
# invenio-config-kth is free software, you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file details.
"""Invenio-theme-kth."""

from .ext import InvenioThemeKTH

__version__ = "1.1.2"
__all__ = ("__version__", "InvenioThemeKTH")
