import TRANSLATE_EN from "./en/translations.json";
import TRANSLATE_SV from "./sv/translations.json";

export const translations = {
  en: { translation: TRANSLATE_EN },
  sv: { translation: TRANSLATE_SV },
};
